import { Component } from '@angular/core';
import { NavController } from 'ionic-angular';
import { Clipboard, Toast } from "ionic-native";
import { CreatePage } from "../create/create";
import { PasswordGenerator } from "../../providers/password-generator";
import { Database } from "../../providers/database";

@Component({
    templateUrl: 'list.html',
})
export class ListPage {

    public passwords: Array<any>;
    public countdown: number;
    private epochSnapshot: number;

    public constructor(private navCtrl: NavController, private passwordGenerator: PasswordGenerator, private database: Database) {
        this.passwords = [];
        this.epochSnapshot = 0;
    }

    public ionViewDidEnter() {
        this.retrievePasswords();
        this.ticker();
    }

    public create() {
        this.navCtrl.push(CreatePage);
    }

    public copy(value: string) {
        Toast.show("Copied to clipboard!", "3000", "bottom").subscribe(
            toast => {
                Clipboard.copy(value);
            }
        );
    }

    private ticker() {
        let epoch = Math.round(new Date().getTime() / 1000.0);
        this.countdown = (30 - (epoch % 30));
        if(epoch % 30 == 0) {
            if(epoch > this.epochSnapshot + 5) {
                this.epochSnapshot = epoch;
                this.retrievePasswords();
            }
        }
        setTimeout(() => {
            this.ticker();
        }, 100);
    }

    private retrievePasswords() {
        this.database.retrieve().then(results => {
            this.passwords = [];
            for(let i = 0; i < results.length; i++) {
                this.passwords.push({
                    "title": results[i].title,
                    "password": this.passwordGenerator.getOTP(results[i].secret)
                });
            }
        }, error => {
            console.error(error);
        });
    }

}