import { Injectable } from '@angular/core';
import { SQLite } from "ionic-native";

@Injectable()
export class Database {

    private isInstantiated: boolean;
    private storage: SQLite;

    public constructor() {
        if(!this.isInstantiated) {
            this.storage = new SQLite();
            this.storage.openDatabase({name: "data.db", location: "default"}).then(() => {
                this.storage.executeSql("CREATE TABLE IF NOT EXISTS passwords (id INTEGER PRIMARY KEY AUTOINCREMENT, title TEXT, secret TEXT)", []);
                this.isInstantiated = true;
            });
        }
    }

    public create(title: string, secret: string) {
        return new Promise((resolve, reject) => {
            this.storage.executeSql("INSERT INTO passwords (title, secret) VALUES (?, ?)", [title, secret]).then((data) => {
                resolve({
                    "title": title,
                    "secret": secret
                });
            }, (error) => {
                reject(error);
            });
        });
    }

    public retrieve(): Promise<any> {
        return new Promise((resolve, reject) => {
            this.storage.executeSql("SELECT id, title, secret FROM passwords", []).then((data) => {
                if(data.rows.length > 0) {
                    let passwords = [];
                    for(let i = 0; i < data.rows.length; i++) {
                        passwords.push({
                            "id": data.rows.item(i).id,
                            "title": data.rows.item(i).title,
                            "secret": data.rows.item(i).secret,
                        });
                    }
                    resolve(passwords);
                }
            }, (error) => {
                reject(error);
            });
        });
    }

}